aboutsummaryrefslogtreecommitdiffstats
path: root/Library/Formula
diff options
context:
space:
mode:
authorDominyk Tiller2014-10-20 17:55:15 +0100
committerMike McQuaid2014-10-21 09:34:02 +0100
commit64c27857b055ead63b80935059ff92d468737c65 (patch)
tree3e49b69ef966055b09eccc0cc5be84a12a51707b /Library/Formula
parentfa6f168b6b7a3aa4eed58df1e5090bc6f93bc035 (diff)
downloadhomebrew-64c27857b055ead63b80935059ff92d468737c65.tar.bz2
subliminal: added colorlog resource
Fixes the issue discussed in [this comment](https://github.com/Homebrew/homebrew/pull/33147#issuecomment-59 666572).
Diffstat (limited to 'Library/Formula')
-rw-r--r--Library/Formula/subliminal.rb9
1 files changed, 7 insertions, 2 deletions
diff --git a/Library/Formula/subliminal.rb b/Library/Formula/subliminal.rb
index 8b7f498a6..a71ba8c7d 100644
--- a/Library/Formula/subliminal.rb
+++ b/Library/Formula/subliminal.rb
@@ -81,11 +81,16 @@ class Subliminal < Formula
sha1 "fbafcd19ea0082b3ecb17695b4cb46070181699f"
end
+ resource "colorlog" do
+ url "https://pypi.python.org/packages/source/c/colorlog/colorlog-2.4.0.tar.gz"
+ sha1 "30b4a621ec372ba4ab367cb5446a4a4293f6e9ed"
+ end
+
def install
ENV.prepend_create_path "PYTHONPATH", "#{libexec}/lib/python2.7/site-packages"
%w[six charade guessit pysrt html5lib enzyme chardet dogpile.core requests babelfish beautifulsoup4 dogpile.cache python-dateutil].each do |r|
resource(r).stage do
- system "python", "setup.py", "install", "--prefix=#{libexec}"
+ system "python", "setup.py", "install", "--prefix=#{libexec}", "--record=installed.txt"
end
end
@@ -81,11 +81,16 @@ class Subliminal < Formula
def install
ENV.prepend_create_path "PYTHONPATH", "#{libexec}/lib/python2.7/site-packages"
- %w[six charade guessit pysrt html5lib enzyme chardet dogpile.core requests babelfish beautifulsoup4 dogpile.cache python-dateutil].each do |r|
+ %w[six charade guessit pysrt html5lib enzyme chardet dogpile.core requests babelfish beautifulsoup4 dogpile.cache python-dateutil colorlog].each do |r|
resource(r).stage do